@@ -415,10 +415,10 @@ impl GeneralReadout for LinuxGeneralReadout {
     fn machine(&self) -> Result<String, ReadoutError> {
         let product_readout = LinuxProductReadout::new();
 
-        let name = product_readout.name()?;
-        let family = product_readout.family()?;
-        let version = product_readout.version()?;
         let vendor = product_readout.vendor()?;
+        let family = product_readout.family()?;
+        let product = product_readout.product()?;
+        let version = extra::pop_newline(fs::read_to_string("/sys/class/dmi/id/product_version")?);
 
         // If one field is generic, the others are likely the same, so fail the readout.
         if vendor.to_lowercase() == "system manufacturer".to_lowercase() {
@@ -427,13 +427,17 @@ impl GeneralReadout for LinuxGeneralReadout {
             )));
         }
 
-        let product = format!("{} {} {} {}", vendor, family, name, version)
+        let new_product = format!("{} {} {} {}", vendor, family, product, version)
             .replace("To be filled by O.E.M.", "");
 
-        if family == name && family == version {
+        if family == product && family == version {
             return Ok(family);
         } else if version.is_empty() || version.len() <= 22 {
-            return Ok(product.split_whitespace().into_iter().unique().join(" "));
+            return Ok(new_product
+                .split_whitespace()
+                .into_iter()
+                .unique()
+                .join(" "));
         }
 
         Ok(version)
@@ -513,12 +517,6 @@ impl ProductReadout for LinuxProductReadout {
         LinuxProductReadout
     }
 
-    fn version(&self) -> Result<String, ReadoutError> {
-        Ok(extra::pop_newline(fs::read_to_string(
-            "/sys/class/dmi/id/product_version",
-        )?))
-    }
-
     fn vendor(&self) -> Result<String, ReadoutError> {
         Ok(extra::pop_newline(fs::read_to_string(
             "/sys/class/dmi/id/sys_vendor",
@@ -530,7 +528,8 @@ impl ProductReadout for LinuxProductReadout {
             "/sys/class/dmi/id/product_family",
         )?))
     }
-    fn name(&self) -> Result<String, ReadoutError> {
+
+    fn product(&self) -> Result<String, ReadoutError> {
         Ok(extra::pop_newline(fs::read_to_string(
             "/sys/class/dmi/id/product_name",
         )?))
@@ -688,44 +687,16 @@ impl LinuxPackageReadout {
     /// that have `homebrew` installed.
     fn count_homebrew() -> Option<usize> {
         if let Ok(home_dir) = std::env::var("HOME") {
-            let linuxbrew = PathBuf::from(home_dir).join(".linuxbrew");
-            if linuxbrew.exists() {
-                let cellar_count = match read_dir(linuxbrew.join("Cellar")) {
-                    Ok(read_dir) => read_dir
-                        .filter(|x| {
-                            if let Ok(entry) = x {
-                                if entry.path().ends_with(".keepme") {
-                                    return false;
-                                }
-
-                                return true;
-                            }
-
-                            false
-                        })
-                        .count(),
-                    Err(_) => 0,
-                };
-
-                let global_count = match read_dir(linuxbrew) {
-                    Ok(read_dir) => read_dir
-                        .filter(|x| {
-                            if let Ok(entry) = x {
-                                if entry.path().is_dir() {
-                                    return false;
-                                }
-
-                                return true;
-                            }
-
-                            false
-                        })
-                        .count(),
-                    Err(_) => 0,
-                };
-
-                return Some(cellar_count + global_count);
+            let mut base = PathBuf::from(home_dir).join(".linuxbrew");
+            if !base.exists() {
+                base = PathBuf::from("/home/linuxbrew/.linuxbrew");
             }
+
+            match read_dir(base.join("Cellar")) {
+                // subtract 1 as $base/Cellar contains a .keepme file
+                Ok(dir) => return Some(dir.count() - 1),
+                Err(_) => return None,
+            };
         }
 
         None
