@@ -1,7 +1,9 @@
 use crate::extra;
 use crate::traits::*;
+use std::collections::HashMap;
 use winreg::enums::*;
 use winreg::RegKey;
+use wmi::{COMLibrary, Variant, WMIConnection};
 
 use windows::{
     Win32::Foundation::PSTR, Win32::System::Power::GetSystemPowerStatus,
@@ -13,6 +15,12 @@ use windows::{
     Win32::System::WindowsProgramming::GetUserNameA,
 };
 
+impl From<wmi::WMIError> for ReadoutError {
+    fn from(e: wmi::WMIError) -> Self {
+        ReadoutError::Other(e.to_string())
+    }
+}
+
 pub struct WindowsBatteryReadout;
 
 impl BatteryReadout for WindowsBatteryReadout {
@@ -253,66 +261,71 @@ impl GeneralReadout for WindowsGeneralReadout {
     }
 
     fn machine(&self) -> Result<String, ReadoutError> {
-        let hklm = RegKey::predef(HKEY_LOCAL_MACHINE);
-        let sys_info = hklm.open_subkey("SYSTEM\\CurrentControlSet\\Control\\SystemInformation")?;
+        let product_readout = WindowsProductReadout::new();
 
-        let manufacturer: String = sys_info.get_value("SystemManufacturer").unwrap();
-        let model: String = sys_info.get_value("SystemProductName").unwrap();
-
-        Ok(format!("{} {}", manufacturer, model))
+        Ok(format!(
+            "{} {}",
+            product_readout.vendor()?,
+            product_readout.product()?
+        ))
     }
 
     fn os_name(&self) -> Result<String, ReadoutError> {
-        let win_version = WindowsVersionInfo::get();
+        let com_con = COMLibrary::new()?;
+        let wmi_con = WMIConnection::new(com_con.into())?;
 
-        match win_version {
-            Ok(v) => Ok(format!("{} ({})", v.name, v.release_id)),
-            Err(e) => Err(ReadoutError::Other(format!(
-                "Trying to get the windows version information \
-            from the registry failed with an error: {:?}",
-                e
-            ))),
+        let results: Vec<HashMap<String, Variant>> =
+            wmi_con.raw_query("SELECT Caption FROM Win32_OperatingSystem")?;
+
+        if let Some(os) = results.first() {
+            if let Some(caption) = os.get("Caption") {
+                if let Variant::String(caption) = caption {
+                    return Ok(format!("{}", caption));
+                }
+            }
         }
+
+        Err(ReadoutError::Other(format!(
+            "Trying to get the operating system name \
+            from WMI failed"
+        )))
     }
 }
 
 pub struct WindowsProductReadout {
-    version_info: Result<WindowsVersionInfo, std::io::Error>,
+    manufacturer: Option<String>,
+    model: Option<String>,
 }
 
 impl ProductReadout for WindowsProductReadout {
     fn new() -> Self {
-        WindowsProductReadout {
-            version_info: WindowsVersionInfo::get(),
-        }
-    }
+        let hklm = RegKey::predef(HKEY_LOCAL_MACHINE);
+        let sys_info = hklm
+            .open_subkey("SYSTEM\\CurrentControlSet\\Control\\SystemInformation")
+            .unwrap();
 
-    fn version(&self) -> Result<String, ReadoutError> {
-        match &self.version_info {
-            Ok(v) => Ok(v.release_id.clone()),
-            Err(e) => Err(ReadoutError::Other(format!(
-                "Trying to get the windows release information \
-            from the registry failed with an error: {:?}",
-                e
-            ))),
+        WindowsProductReadout {
+            manufacturer: sys_info.get_value("SystemManufacturer").ok(),
+            model: sys_info.get_value("SystemProductName").ok(),
         }
     }
 
     fn vendor(&self) -> Result<String, ReadoutError> {
-        Ok(String::from("Microsoft"))
+        match &self.manufacturer {
+            Some(v) => Ok(v.clone()),
+            None => Err(ReadoutError::Other(format!(
+                "Trying to get the system manufacturer \
+                from the registry failed"
+            ))),
+        }
     }
 
-    fn family(&self) -> Result<String, ReadoutError> {
-        Ok(String::from("Windows"))
-    }
-
-    fn name(&self) -> Result<String, ReadoutError> {
-        match &self.version_info {
-            Ok(v) => Ok(v.name.clone()),
-            Err(e) => Err(ReadoutError::Other(format!(
-                "Trying to get the windows version information \
-            from the registry failed with an error: {:?}",
-                e
+    fn product(&self) -> Result<String, ReadoutError> {
+        match &self.model {
+            Some(v) => Ok(v.clone()),
+            None => Err(ReadoutError::Other(format!(
+                "Trying to get the system product name \
+                from the registry failed"
             ))),
         }
     }
@@ -345,20 +358,3 @@ impl WindowsPackageReadout {
         crate::shared::count_cargo()
     }
 }
-
-struct WindowsVersionInfo {
-    name: String,
-    release_id: String,
-}
-
-impl WindowsVersionInfo {
-    fn get() -> Result<Self, std::io::Error> {
-        let hklm = RegKey::predef(HKEY_LOCAL_MACHINE);
-        let nt_current = hklm.open_subkey("SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion")?;
-
-        let name: String = nt_current.get_value("ProductName").unwrap();
-        let release_id: String = nt_current.get_value("ReleaseId").unwrap();
-
-        Ok(WindowsVersionInfo { name, release_id })
-    }
-}
